==> easysnowdata-0.0.11.tar.gz: easysnowdata-0.0.11/README.md <==
# easysnowdata


[![image](https://img.shields.io/pypi/v/easysnowdata.svg)](https://pypi.python.org/pypi/easysnowdata)
[![image](https://img.shields.io/conda/vn/conda-forge/easysnowdata.svg)](https://anaconda.org/conda-forge/easysnowdata)


**package to easily get data relevant to snow**

easysnowdata is a package for retrieving all types of data relevant to snow, with an emphasis on minimizing downloads and local computations. Data is primarily ouput in xarray objects. This is a package primarily for personal use, so design decisions made are often tailored to my particular use cases. Feel free to contribute! Package is under heavy construction for the time being.

## gallery
![easysnowdata](https://github.com/user-attachments/assets/5b2c83a4-b732-4c35-86fd-1bccb954c286)

## installation
`pip install easysnowdata`

## examples

[quickstart](https://github.com/egagli/easysnowdata/blob/main/docs/examples/how_easy.ipynb)

[remote_sensing module examples](https://nbviewer.org/github/egagli/easysnowdata/blob/main/docs/examples/remote_sensing_examples.ipynb)

[hydroclimatology module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/hydroclimatology_examples.ipynb)

[automatic_weather_stations module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/automatic_weather_station_examples.ipynb)

[topography module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/topography_examples.ipynb)

[full examples folder](https://github.com/egagli/easysnowdata/tree/main/docs/examples)

## documentation 
https://egagli.github.io/easysnowdata
    

## to do list

-   [list of data products to add](https://github.com/egagli/easysnowdata/issues/11)

==> easysnowdata-0.0.20.tar.gz: easysnowdata-0.0.20/README.md <==
# easysnowdata


[![image](https://img.shields.io/pypi/v/easysnowdata.svg)](https://pypi.python.org/pypi/easysnowdata)
[![image](https://img.shields.io/conda/vn/conda-forge/easysnowdata.svg)](https://anaconda.org/conda-forge/easysnowdata)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14741502.svg)](https://doi.org/10.5281/zenodo.14741502)


**package to easily get data relevant to snow**

easysnowdata is a package for retrieving all types of data relevant to snow, with an emphasis on minimizing downloads and local computations. Data is primarily ouput in xarray objects. This is a package primarily for personal use, so design decisions made are often tailored to my particular use cases. Feel free to contribute! Package is under heavy construction for the time being.

## gallery
![easysnowdata](https://github.com/user-attachments/assets/5b2c83a4-b732-4c35-86fd-1bccb954c286)

## installation
easysnowdata is available on pypi and conda-forge. you can install easysnowdata with any of the following...

*  `pip install easysnowdata`     
*  `conda install easysnowdata`    
*  `mamba install easysnowdata`

## examples

[quickstart](https://github.com/egagli/easysnowdata/blob/main/docs/examples/how_easy.ipynb)

[remote_sensing module examples](https://nbviewer.org/github/egagli/easysnowdata/blob/main/docs/examples/remote_sensing_examples.ipynb)

[hydroclimatology module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/hydroclimatology_examples.ipynb)

[automatic_weather_stations module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/automatic_weather_station_examples.ipynb)

[topography module examples](https://github.com/egagli/easysnowdata/blob/main/docs/examples/topography_examples.ipynb)

[full examples folder](https://github.com/egagli/easysnowdata/tree/main/docs/examples)

## documentation 
https://egagli.github.io/easysnowdata
    

## to do list

-   [list of data products to add](https://github.com/egagli/easysnowdata/issues/11)
